@@ -24,6 +24,7 @@ class CsvSource(Source):
         if self.url.scheme != 'file':
             assert self.url.scheme == 'file', str(self.url)
 
+
         self._meta = {}
 
     def __iter__(self):
@@ -47,11 +48,10 @@ class CsvSource(Source):
         self.start()
 
         try:
-
-            # Python 3.6 considers None to mean 'utf8', but Python 3.5 considers it to be 'ascii'
             encoding = self.url.encoding or 'utf8'
 
             with open(self.url.fspath, encoding=encoding) as f:
+
                 yield from csv.reader(f, delimiter=self.delimiter)
 
         except UnicodeError as e:
@@ -82,11 +82,15 @@ class CsvSource(Source):
         if self.url.encoding and not 'encoding' in kwargs:
             kwargs['encoding'] = self.url.encoding
 
+        if not 'sep' in kwargs:
+            kwargs['sep'] = self.delimiter
+
         last_exception = None
 
         while True:
 
             try:
+
                 return pandas.read_csv(self.url.fspath, *args, **kwargs)
             except Exception as e:
                 last_exception = e
